@@ -1,5 +1,4 @@
-#ifndef APPSETTINGS_H
-#define APPSETTINGS_H
+#pragma once 
 
 #include <QObject>
 #include <QSettings>
@@ -13,6 +12,8 @@
 class SettingSection : public QObject
 {
     Q_OBJECT
+    Q_DISABLE_COPY(SettingSection)
+    
     Q_PROPERTY(QString key READ key WRITE setKey NOTIFY keyChanged)
     Q_PROPERTY(QString group READ group WRITE setGroup NOTIFY groupChanged)
     Q_PROPERTY(QVariant defaultValue READ defaultValue WRITE setDefaultValue NOTIFY defaultValueChanged)
@@ -29,13 +30,13 @@ public:
     QVariant defaultValue() const;
     QVariant value() const;
 
-public slots:
+public Q_SLOTS:
     void setKey(QString key);
     void setGroup(QString group);
     void setValue(QVariant value);
     void setDefaultValue(QVariant defaultValue);
 
-signals:
+Q_SIGNALS:
     void keyChanged(QString key);
     void groupChanged(QString group);
     void defaultValueChanged(QVariant defaultValue);
@@ -48,6 +49,8 @@ signals:
 class MAUIKIT_EXPORT AppSettings : public QObject
 {
     Q_OBJECT
+    Q_DISABLE_COPY(AppSettings)
+    
 public:
     /**
      * @brief local
@@ -69,8 +72,6 @@ public:
         return settings;
     }
 
-    AppSettings(const AppSettings &) = delete;
-    AppSettings &operator=(const AppSettings &) = delete;
     AppSettings(AppSettings &&) = delete;
     AppSettings &operator=(AppSettings &&) = delete;
 
@@ -104,7 +105,7 @@ private:
     QString m_org;
     QSettings *m_settings;
 
-signals:
+Q_SIGNALS:
     /**
      * @brief settingChanged
      * @param url
@@ -115,4 +116,3 @@ signals:
     void settingChanged(QUrl url, QString key, QVariant value, QString group);
 };
 
-#endif // APPSETTINGS_H
