@@ -23,7 +23,6 @@
 
 Q_GLOBAL_STATIC(ImageTexturesCache, s_iconImageCache)
 
-#include "style.h"
 #include <MauiMan/thememanager.h>
 
 Icon::Icon(QQuickItem *parent)
@@ -40,6 +39,7 @@ Icon::Icon(QQuickItem *parent)
     connect(qApp, &QGuiApplication::paletteChanged, this, &QQuickItem::polish);
     connect(this, &QQuickItem::enabledChanged, this, &QQuickItem::polish);
     connect(this, &QQuickItem::smoothChanged, this, &QQuickItem::polish);
+
 }
 
 Icon::~Icon()
@@ -61,17 +61,6 @@ void Icon::setSource(const QVariant &icon)
         connect(m_theme, &Maui::PlatformTheme::PlatformTheme::colorsChanged, this, &QQuickItem::polish);
     }
 
-    if(!m_style)
-    {
-        m_style = static_cast<Style *>(qmlAttachedPropertiesObject<Style>(this, true));
-
-//        connect(m_style, &Style::currentIconThemeChanged, [this](QString)
-//        {
-//           this->setEnabled(false);
-//            this->setEnabled(true);
-//        });
-    }
-
     if (icon.type() == QVariant::String) {
         const QString iconSource = icon.toString();
         m_isMaskHeuristic = (iconSource.endsWith(QLatin1String("-symbolic")) //
