@@ -29,13 +29,6 @@
 #include <KLocalizedString>
 #include <KCoreAddons>
 
-#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
-#include <KConfig>
-#include <KConfigGroup>
-#include <KSharedConfig>
-#include <QFileSystemWatcher>
-#endif
-
 #if defined BUNDLE_LUV_ICONS
 #include <QIcon>
 #endif
@@ -57,6 +50,8 @@ KAboutComponent MauiApp::aboutMauiKit()
 MauiApp::MauiApp()
     : QObject(nullptr)
     , m_controls(new CSDControls(this))
+    ,m_themeSettings( new MauiMan::ThemeManager(this))
+
 {
     qDebug() << "CREATING INSTANCE OF MAUI APP";
     connect(qApp, &QCoreApplication::aboutToQuit, []()
@@ -67,26 +62,26 @@ MauiApp::MauiApp()
     });
     
     KAboutData aboutData(KAboutData::applicationData());
-    if (aboutData.translators().isEmpty()) 
+    if (aboutData.translators().isEmpty())
     {
         aboutData.setTranslator(i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"), //
                                 i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
 
     }
-        aboutData.addComponent("Qt", "", QT_VERSION_STR, "https://qt.io");
-   
-        aboutData.addComponent(i18n("KDE Frameworks"), "", KCoreAddons::versionString(), "https://kde.org");
+    aboutData.addComponent("Qt", "", QT_VERSION_STR, "https://qt.io");
 
-aboutData.addComponent(i18n("MauiKit Frameworks"), "", MauiApp::getMauikitVersion(), "https://mauikit.org", KAboutLicense::GPL_V3);           
+    aboutData.addComponent(i18n("KDE Frameworks"), "", KCoreAddons::versionString(), "https://kde.org");
+
+    aboutData.addComponent(i18n("MauiKit Frameworks"), "", MauiApp::getMauikitVersion(), "https://mauikit.org", KAboutLicense::GPL_V3);
 
 #if defined BUNDLE_LUV_ICONS
-aboutData.addComponent(i18n("Luv Icon Theme"), "", "", "https://github.com/Nitrux/luv-icon-theme", KAboutLicense::Artistic);           
-
+    aboutData.addComponent(i18n("Luv Icon Theme"), "", "", "https://github.com/Nitrux/luv-icon-theme", KAboutLicense::Artistic);
 #endif
 
-KAboutData::setApplicationData(aboutData);
+    KAboutData::setApplicationData(aboutData);
 
     setDefaultMauiStyle();
+   
 }
 
 QString MauiApp::getMauikitVersion()
@@ -105,7 +100,7 @@ void MauiApp::setIconName(const QString &value)
         return;
     
     m_iconName = value;
-    emit this->iconNameChanged();
+    Q_EMIT this->iconNameChanged();
 }
 
 QString MauiApp::getDonationPage() const
@@ -119,7 +114,7 @@ void MauiApp::setDonationPage(const QString &value)
         return;
     
     m_donationPage = value;
-    emit this->donationPageChanged();
+    Q_EMIT this->donationPageChanged();
 }
 
 KAboutData MauiApp::getAbout() const
@@ -135,7 +130,7 @@ void MauiApp::setDefaultMauiStyle()
     QIcon::setThemeName("Luv");
 #endif
     
-    Q_INIT_RESOURCE(style);
+//    Q_INIT_RESOURCE(style);
     QQuickStyle::setStyle("maui-style");
 }
 
@@ -162,7 +157,7 @@ void MauiApp::setTranslucencyAvailable(const bool &value)
     }
 
     m_translucencyAvailable = value;
-    emit this->translucencyAvailableChanged(m_translucencyAvailable);
+    Q_EMIT this->translucencyAvailableChanged(m_translucencyAvailable);
 }
 
 MauiApp *MauiApp::qmlAttachedProperties(QObject *object)
@@ -172,34 +167,25 @@ MauiApp *MauiApp::qmlAttachedProperties(QObject *object)
 }
 
 CSDControls::CSDControls(QObject *parent) : QObject (parent)
-,m_themeSettings( new MauiMan::ThemeManager(this))
-
+  ,m_themeSettings( new MauiMan::ThemeManager(this))
 {       
     connect(m_themeSettings, &MauiMan::ThemeManager::enableCSDChanged, [this](bool enabled)
-    {        
-        qDebug() << "CSD ENABLED CHANGED<<<<" << enabled; 
+    {
+        qDebug() << "CSD ENABLED CHANGED<<<<" << enabled;
         
-        if(m_enabledCSD_blocked)
-            return;
-        
-        m_enableCSD = enabled;
-        Q_EMIT enableCSDChanged();
+        getWindowControlsSettings();
     });
     
     connect(m_themeSettings, &MauiMan::ThemeManager::windowControlsThemeChanged, [this](QString style)
-    {        
+    {
         m_styleName = style;
-        setStyle(); 
+        setStyle();
         
         Q_EMIT styleNameChanged();
         Q_EMIT sourceChanged();
     });
- 
-//     connect(this, &CSDControls::styleNameChanged, [this]()
-//     {
-//     });
     
-    getWindowControlsSettings();     
+    getWindowControlsSettings();
 }
 
 void CSDControls::setStyle()
@@ -218,37 +204,47 @@ void CSDControls::setStyle()
     
     qDebug() << "CSD QML SOURCXE" << m_source;
     m_rightWindowControls =  QStringList {"I", "A", "X"};
-    emit this->rightWindowControlsChanged();    
 }
 
 void CSDControls::getWindowControlsSettings()
-{    
-    #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+{        
+    if(m_enabledCSD_blocked)
+        return;
+    
+    m_enableCSD = m_themeSettings->enableCSD();
+    Q_EMIT enableCSDChanged();
+    
+    /*  #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+
+    #ifdef FORMFACTOR_FOUND
+    
+    if(m_formFactor->preferredMode() == 0)
+    {
+        m_enableCSD = m_themeSettings->enableCSD();
+        Q_EMIT enableCSDChanged();
+        
+    }else
+    {
+        m_enableCSD = false;
+        Q_EMIT enableCSDChanged();
+        return;
+    }
+#else //Fallback in case FormFactor is not found. and then check for the env var QT_QUICK_CONTROLS_MOBILE
     if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE"))
     {
         if (QByteArrayList {"0", "false"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE")))
         {
             m_enableCSD = m_themeSettings->enableCSD();
+            Q_EMIT enableCSDChanged();
         }else
         {
-            return;    
+            return;
         }
-    }else
-    {
-        m_enableCSD = m_themeSettings->enableCSD();
     }
+    #endif  */
     
     m_styleName = m_themeSettings->windowControlsTheme();
     setStyle();
-    
-    #elif defined Q_OS_MACOS || defined Q_OS_ANDROID
-    m_leftWindowControls = QStringList {"X", "I", "A"};
-    emit this->leftWindowControlsChanged();
-    
-    #elif defined Q_OS_WIN32
-    //   m_rightWindowControls = QStringList {"I", "A", "X"};
-    emit this->rightWindowControlsChanged();
-    #endif
 }
 
 bool CSDControls::enableCSD() const
@@ -262,10 +258,16 @@ void CSDControls::setEnableCSD(const bool &value)
     if (m_enableCSD == value)
         return;
     
-    m_enableCSD = value;        
+    m_enableCSD = value;
     Q_EMIT enableCSDChanged();
 }
 
+void CSDControls::resetEnableCSD()
+{
+    m_enabledCSD_blocked = false;
+    getWindowControlsSettings();
+}
+
 QUrl CSDControls::source() const
 {
     return m_source;
@@ -279,9 +281,12 @@ QString CSDControls::styleName() const
 CSDButton::CSDButton(QObject *parent): QObject(parent)
 {
     connect(this, &CSDButton::typeChanged, this, &CSDButton::setSources);
-    connect(this, &CSDButton::styleChanged, this, &CSDButton::setSources);
+    // connect(this, &CSDButton::styleChanged, this, &CSDButton::setSources);
     connect(this, &CSDButton::stateChanged, this, &CSDButton::requestCurrentSource);
+    // connect(MauiApp::instance()->controls(), &CSDControls::styleNameChanged, this, &CSDButton::setSources);
+    
     m_style = MauiApp::instance()->controls()->styleName();
+    setSources();
 }
 
 void CSDButton::setStyle(const QString& style)
@@ -348,8 +353,8 @@ QUrl CSDButton::extractStateValue(QSettings &settings, const CSDButton::CSDButto
 
 void CSDButton::requestCurrentSource()
 {
-    this->m_source = this->m_sources.value (this->m_state);
-    emit this->sourceChanged ();
+    m_source = this->m_sources.value (this->m_state);
+    Q_EMIT this->sourceChanged ();
 }
 
 QString CSDButton::mapButtonType(const CSDButtonType &type)
@@ -383,7 +388,7 @@ void CSDButton::setState(const CSDButtonState &newState)
     if (m_state == newState)
         return;
     m_state = newState;
-    emit stateChanged();
+    Q_EMIT stateChanged();
 }
 
 CSDControls *MauiApp::controls() const
@@ -402,7 +407,7 @@ void CSDButton::setType(CSDButtonType newType)
         return;
     
     m_type = newType;
-    emit typeChanged();
+    Q_EMIT typeChanged();
 }
 
 CSDButton::CSDButtonType CSDButton::mapType(const QString &value)
@@ -429,9 +434,9 @@ void CSDButton::setIsHovered(bool newIsHovered)
         this->setState (CSDButtonState::Hover);
     }else
     {
-        this->setState (CSDButtonState::Normal);
+        this->setState (m_isFocused ? CSDButtonState::Normal : CSDButtonState::Backdrop);
     }
-    emit isHoveredChanged();
+    Q_EMIT isHoveredChanged();
 }
 
 bool CSDButton::isMaximized() const
@@ -451,7 +456,7 @@ void CSDButton::setIsMaximized(bool newIsMaximized)
     {
         this->setType (CSDButtonType::Maximize);
     }
-    emit isMaximizedChanged();
+    Q_EMIT isMaximizedChanged();
 }
 
 bool CSDButton::isPressed() const
@@ -471,7 +476,7 @@ void CSDButton::setIsPressed(bool newIsPressed)
     {
         this->setState (CSDButtonState::Normal);
     }
-    emit isPressedChanged();
+    Q_EMIT isPressedChanged();
 }
 
 bool CSDButton::isFocused() const
@@ -493,23 +498,5 @@ void CSDButton::setIsFocused(bool newIsFocused)
     {
         this->setState (CSDButtonState::Backdrop);
     }
-    emit isFocusedChanged();
-}
-
- void CSDControls::applyRadius(QWindow *window, int radius)
- {
-    
-    QRect r(QPoint(), window->geometry().size());
-    QRect rb(0, 0, 2 * radius, 2 * radius);
-    
-    QRegion region(rb, QRegion::Ellipse);
-    rb.moveRight(r.right());
-    region += QRegion(rb, QRegion::Ellipse);
-    rb.moveBottom(r.bottom());
-    region += QRegion(rb, QRegion::Ellipse);
-    rb.moveLeft(r.left());
-    region += QRegion(rb, QRegion::Ellipse);
-    region += QRegion(r.adjusted(radius, 0, -radius, 0), QRegion::Rectangle);
-    region += QRegion(r.adjusted(0, radius, 0, -radius), QRegion::Rectangle);
-    window->setMask(region);
+    Q_EMIT isFocusedChanged();
 }
