@@ -317,9 +317,27 @@ void WheelHandler::setScrolling(bool scrolling)
         return;
     }
     m_wheelScrolling = scrolling;
+    m_verticalScrollBar->setProperty("active", scrolling);
     m_filterItem->setEnabled(m_wheelScrolling);
 }
 
+Qt::Orientation WheelHandler::primaryOrientation() const
+{
+    return m_primaryOrientation;
+}
+
+void WheelHandler::setPrimaryOrientation(Qt::Orientation orientation)
+{
+    if(m_primaryOrientation == orientation)
+    {
+        return;
+    }
+    
+    m_primaryOrientation = orientation;
+    Q_EMIT primaryOrientationChanged();
+}
+
+
 bool WheelHandler::scrollFlickable(QPointF pixelDelta, QPointF angleDelta, Qt::KeyboardModifiers modifiers)
 {
     if (!m_flickable || (pixelDelta.isNull() && angleDelta.isNull())) {
@@ -344,7 +362,7 @@ bool WheelHandler::scrollFlickable(QPointF pixelDelta, QPointF angleDelta, Qt::K
     const qreal devicePixelRatio = window != nullptr ? window->devicePixelRatio() : qGuiApp->devicePixelRatio();
 
     // HACK: Only transpose deltas when not using xcb in order to not conflict with xcb's own delta transposing
-    if (modifiers & m_defaultHorizontalScrollModifiers && qGuiApp->platformName() != QLatin1String("xcb")) {
+    if (m_primaryOrientation == Qt::Orientation::Horizontal) {
         angleDelta = angleDelta.transposed();
         pixelDelta = pixelDelta.transposed();
     }
@@ -528,6 +546,7 @@ bool WheelHandler::eventFilter(QObject *watched, QEvent *event)
         }
         setScrolling(scrolled);
 
+        qDebug() << "Wheel event" << scrolled << m_blockTargetWheel;
         // NOTE: Wheel events created by touchpad gestures with pixel deltas will cause scrolling to jump back
         // to where scrolling started unless the event is always accepted before it reaches the Flickable.
         bool flickableWillUseGestureScrolling = !(wheelEvent->source() == Qt::MouseEventNotSynthesized || wheelEvent->pixelDelta().isNull());
